@@ -4,11 +4,11 @@ var searchData=
   ['permission_1',['Permission',['../group__pw__permission.html',1,'']]],
   ['plugin_20handle_2',['Plugin Handle',['../group__spa__handle.html',1,'']]],
   ['plugin_20loader_3',['Plugin Loader',['../group__spa__plugin__loader.html',1,'']]],
-  ['pod_4',['POD',['../group__spa__pod.html',1,'']]],
+  ['pod_4',['POD',['../group__spa__json__pod.html',1,'JSON to POD'],['../group__spa__pod.html',1,'POD']]],
   ['port_5',['Port',['../group__pw__port.html',1,'']]],
   ['port_20impl_6',['Port Impl',['../group__pw__impl__port.html',1,'']]],
   ['profiler_7',['Profiler',['../group__pw__profiler.html',1,'']]],
   ['properties_8',['Properties',['../group__pw__properties.html',1,'']]],
-  ['protocol_9',['Protocol',['../group__pw__protocol.html',1,'']]],
+  ['protocol_9',['Protocol',['../group__pw__protocol__native.html',1,'Native Protocol'],['../group__pw__protocol.html',1,'Protocol']]],
   ['proxy_10',['Proxy',['../group__pw__proxy.html',1,'']]]
 ];
